package javax.management;

import java.util.Iterator;
import java.util.Vector;
import java.util.List;

public class NotificationFilterSupport implements NotificationFilter
{
    private static final long serialVersionUID = 6579080007561786969L;
    private List<String> enabledTypes;
    
    public NotificationFilterSupport() {
        this.enabledTypes = new Vector();
    }
    
    @Override
    public synchronized boolean isNotificationEnabled(Notification notification) {
        String type = notification.getType();
        if (type == null) {
            return false;
        }
        try {
            Iterator<String> iterator = this.enabledTypes.iterator();
            while (iterator.hasNext()) {
                if (type.startsWith((String)iterator.next())) {
                    return true;
                }
                continue;
            }
        }
        catch (NullPointerException ex) {
            return false;
        }
        return false;
    }
    
    public synchronized void enableType(String s) throws IllegalArgumentException {
        if (s == null) {
            throw new IllegalArgumentException("The prefix cannot be null.");
        }
        if (!this.enabledTypes.contains(s)) {
            this.enabledTypes.add(s);
        }
        return;
    }
    
    public synchronized void disableType(String s) {
        this.enabledTypes.remove(s);
    }
    
    public synchronized void disableAllTypes() {
        this.enabledTypes.clear();
    }
    
    public synchronized Vector<String> getEnabledTypes() {
        return (Vector)this.enabledTypes;
    }
}
